Index: Makefile
===================================================================
--- Makefile	(revision 350763)
+++ Makefile	(working copy)
@@ -11,6 +11,8 @@
 MAINTAINER=	osa@FreeBSD.org
 COMMENT=	Modules for running Ruby on Rails and Rack applications
 
+LICENSE=	MIT
+
 OPTIONS_DEFINE=	DEBUG SYMLINK
 OPTIONS_SINGLE=	SERVER
 OPTIONS_SINGLE_SERVER=	APACHE22 NGINX
@@ -37,11 +39,10 @@
 .else
 BUILD_DEPENDS+=	nginx:${PORTSDIR}/www/nginx-devel
 .endif
-.endif
 
-LIB_DEPENDS+=	eio:${PORTSDIR}/devel/libeio \
-		ev:${PORTSDIR}/devel/libev \
-		curl:${PORTSDIR}/ftp/curl
+LIB_DEPENDS+=	libeio.so:${PORTSDIR}/devel/libeio \
+		libev.so:${PORTSDIR}/devel/libev \
+		libcurl.so:${PORTSDIR}/ftp/curl
 BUILD_DEPENDS+=	rubygem-fastthread>=1.0.1:${PORTSDIR}/devel/rubygem-fastthread \
 		rubygem-rack>=0:${PORTSDIR}/www/rubygem-rack \
 		rubygem-daemon_controller>=1.2.0:${PORTSDIR}/devel/rubygem-daemon_controller
@@ -48,7 +49,13 @@
 RUN_DEPENDS:=	${BUILD_DEPENDS}
 
 SUB_LIST+=	GEM_LIB_DIR=${GEM_LIB_DIR} RUBY=${RUBY}
-SUB_FILES=	pkg-message
+.if ${PORT_OPTIONS:MNGINX}
+SUB_FILES+=	pkg-message-nginx
+PKGMESSAGE=	pkg-message-nginx
+.elif defined(WITH_APACHEPORT)
+SUB_FILES+=	pkg-message-apache
+PKGMESSAGE=	pkg-message-apache
+.endif
 
 PLIST_FILES=	bin/passenger \
 		bin/passenger-config \
@@ -81,7 +88,7 @@
 		s! -feliminate-unused-debug-symbols -feliminate-unused-debug-types!!g; \
 		201,203s!true!false!' \
 		${WRKSRC}/build/basics.rb
-.if ${PORT_OPTIONS:NDEBUG}
+.if ${PORT_OPTIONS:MDEBUG}
 	@${REINPLACE_CMD} \
 		's!-DPASSENGER_DEBUG!-DNDEBUG!g' \
 		${WRKSRC}/build/basics.rb
@@ -101,19 +108,23 @@
 		's!-lpthread!${PTHREAD_LIBS}!g' \
 		${WRKSRC}/lib/phusion_passenger/platform_info/cxx_portability.rb
 
-post-build:
+post-install:
 .if ${PORT_OPTIONS:MAPACHE22}
-	(CC=${CC} CXX=${CXX} ${WRKSRC}/bin/passenger-install-apache2-module --auto)
+	(CC=${CC} CXX=${CXX} ${STAGEDIR}${PREFIX}/bin/passenger-install-apache2-module --auto)
 .endif
 
 .if ${PORT_OPTIONS:MNGINX}
-	(cd ${WRKSRC} && CC=${CC} CXX=${CXX} ${RAKE_BIN} nginx)
+	(cd ${STAGEDIR}${PREFIX}/${GEMS_DIR}/${GEM_NAME} && CC=${CC} CXX=${CXX} ${RAKE_BIN} nginx)
 .endif
 .if ${PORT_OPTIONS:MSYMLINK}
-	${LN} -s ${GEM_LIB_DIR} ${STAGE}${PREFIX}/${GEMS_DIR}/${PORTNAME}
+	${LN} -s ${GEM_LIB_DIR} ${STAGEDIR}${PREFIX}/${GEMS_DIR}/${PORTNAME}
 .endif
 
-	${FIND} ${WRKSRC} -name '*.o' -delete
-	${FIND} ${WRKSRC} -name '*.bak' -delete
+	${FIND} ${STAGEDIR} -name '*.o' -delete
+	${FIND} ${STAGEDIR} -name '*.bak' -delete
+	${FIND} ${STAGEDIR} -name '*.log' -delete
+	${RM} -rf ${STAGEDIR}${PREFIX}/${GEMS_DIR}/${GEM_NAME}/buildout/common
+	${RM} -rf ${STAGEDIR}${PREFIX}/${GEMS_DIR}/${GEM_NAME}/buildout/cache
+	${FIND} ${STAGEDIR}${PREFIX}/${GEMS_DIR}/${GEM_NAME}/buildout/ruby/ -name Makefile -delete
 
 .include <bsd.port.mk>
Index: files/pkg-message-nginx.in
===================================================================
--- files/pkg-message-nginx.in	(revision 0)
+++ files/pkg-message-nginx.in	(working copy)
@@ -0,0 +1,12 @@
+#####################################################################
+
+Please edit your nginx configuration file, and add these lines:
+
+   passenger_root %%PREFIX%%/%%GEM_LIB_DIR%%
+   passenger_ruby %%RUBY%%
+
+After you restart nginx, you are ready to deploy any number of Ruby on Rails
+applications on nginx, without any further Ruby on Rails-specific
+configuration!
+
+#####################################################################

Property changes on: files/pkg-message-nginx.in
___________________________________________________________________
Added: fbsd:nokeywords
## -0,0 +1 ##
+yes
\ No newline at end of property
Added: svn:eol-style
## -0,0 +1 ##
+native
\ No newline at end of property
Added: svn:mime-type
## -0,0 +1 ##
+text/plain
\ No newline at end of property
Index: files/pkg-message.in
===================================================================
--- files/pkg-message.in	(revision 350763)
+++ files/pkg-message.in	(working copy)
@@ -1,13 +0,0 @@
-#####################################################################
-
-Please edit your Apache configuration file, and add these lines:
-
-   LoadModule passenger_module %%PREFIX%%/%%GEM_LIB_DIR%%/buildout/apache2/mod_passenger.so
-   PassengerRoot %%PREFIX%%/%%GEM_LIB_DIR%%
-   PassengerRuby %%RUBY%%
-
-After you restart Apache, you are ready to deploy any number of Ruby on Rails
-applications on Apache, without any further Ruby on Rails-specific
-configuration!
-
-#####################################################################
